@@ -4,6 +4,7 @@ This module provides utilities for backup management.
 - backup_cli: Main entry point for command line usage
 - create_delta_backup: Creates a ZIP delta backup, saving only modified or new files while tracking deleted files
 - consolidate_backups: Consolidates the files from the given backup and all previous ones into a new ZIP file
+- limit_backups: Limits the number of delta backups by consolidating the oldest ones
 - get_file_hash: Computes the SHA-256 hash of a file
 - extract_hash_from_zipinfo: Extracts the stored hash from a ZipInfo object's comment
 - get_all_previous_backups: Retrieves all previous backups in a folder and maps each backup to a dictionary of file paths and their hashes
@@ -24,7 +25,7 @@ import zipfile
 # Local imports
 from .decorators import handle_error, measure_time
 from .io import clean_path
-from .print import colored_for_loop, info, progress, warning
+from .print import CYAN, GREEN, RESET, colored_for_loop, info, warning
 
 # Constants
 CHUNK_SIZE = 1048576  # 1MB chunks for I/O operations
@@ -32,8 +33,7 @@ LARGE_CHUNK_SIZE = 8388608  # 8MB chunks for large file operations
 
 
 # Main entry point for command line usage
-@measure_time(progress)
-def backup_cli():
+def backup_cli() -> None:
 	""" Main entry point for command line usage.
 
 	Examples:
@@ -45,14 +45,22 @@ def backup_cli():
 
 		# Consolidate backups into a single file
 		python -m stouputils.backup consolidate /path/to/backups/latest.zip /path/to/consolidated.zip
+
+		# Limit the number of delta backups to 5
+		python -m stouputils.backup limit 5 /path/to/backups
 	"""
 	import argparse
 
 	# Setup command line argument parser
 	parser: argparse.ArgumentParser = argparse.ArgumentParser(
-		description="Backup and consolidate files using delta compression."
+		description="Backup and consolidate files using delta compression.",
+		formatter_class=argparse.RawDescriptionHelpFormatter,
+		epilog=f"""{CYAN}Examples:{RESET}
+  stouputils backup delta /path/to/source /path/to/backups -x "*.pyc"
+  stouputils backup consolidate /path/to/backups/latest.zip /path/to/output.zip
+  stouputils backup limit 5 /path/to/backups"""
 	)
-	subparsers = parser.add_subparsers(dest="command", required=True)
+	subparsers = parser.add_subparsers(dest="command", required=False)
 
 	# Create delta command and its arguments
 	delta_psr = subparsers.add_parser("delta", help="Create a new delta backup")
@@ -65,13 +73,37 @@ def backup_cli():
 	consolidate_psr.add_argument("backup_zip", type=str, help="Path to the latest backup ZIP file")
 	consolidate_psr.add_argument("destination_zip", type=str, help="Path to the destination consolidated ZIP file")
 
+	# Create limit command and its arguments
+	limit_psr = subparsers.add_parser("limit", help="Limit the number of delta backups by consolidating the oldest ones")
+	limit_psr.add_argument("max_backups", type=int, help="Maximum number of delta backups to keep")
+	limit_psr.add_argument("backup_folder", type=str, help="Path to the folder containing backups")
+	limit_psr.add_argument("--no-keep-oldest", dest="keep_oldest", action="store_false", default=True, help="Allow deletion of the oldest backup (default: keep it)")
+
 	# Parse arguments and execute appropriate command
 	args: argparse.Namespace = parser.parse_args()
 
+	# Show custom help if no command is provided
+	if not args.command:
+		separator: str = "─" * 60
+		print(f"{CYAN}{separator}{RESET}")
+		print(f"{CYAN}Backup Utilities{RESET}")
+		print(f"{CYAN}{separator}{RESET}")
+		print(f"\n{CYAN}Usage:{RESET} stouputils backup <command> [options]")
+		print(f"\n{CYAN}Available commands:{RESET}")
+		print(f"  {GREEN}delta{RESET}         Create a new delta backup")
+		print(f"  {GREEN}consolidate{RESET}   Consolidate existing backups into one")
+		print(f"  {GREEN}limit{RESET}         Limit the number of delta backups")
+		print(f"\n{CYAN}For detailed help on a specific command:{RESET}")
+		print("  stouputils backup <command> --help")
+		print(f"{CYAN}{separator}{RESET}")
+		return
+
 	if args.command == "delta":
 		create_delta_backup(args.source, args.destination, args.exclude)
 	elif args.command == "consolidate":
 		consolidate_backups(args.backup_zip, args.destination_zip)
+	elif args.command == "limit":
+		limit_backups(args.max_backups, args.backup_folder, keep_oldest=args.keep_oldest)
 
 # Main backup function that creates a delta backup (only changed files)
 @measure_time(message="Creating ZIP backup")
@@ -263,6 +295,10 @@ def consolidate_backups(zip_path: str, destination_zip: str) -> None:
 				except Exception as e:
 					warning(f"Error copying file {filename} from {backup_path}: {e}")
 					continue
+
+			# Add accumulated deleted files to the consolidated backup
+			if deleted_files:
+				zipf_out.writestr("__deleted_files__.txt", "\n".join(sorted(deleted_files)), compress_type=zipfile.ZIP_DEFLATED)
 	finally:
 		# Clean up open ZIP files
 		for zipf in open_zips.values():
@@ -273,6 +309,84 @@ def consolidate_backups(zip_path: str, destination_zip: str) -> None:
 
 	info(f"Consolidated backup created: {destination_zip}")
 
+# Function to limit the number of delta backups by consolidating the oldest ones
+@measure_time(message="Limiting backups")
+@handle_error()
+def limit_backups(max_backups: int, backup_folder: str, keep_oldest: bool = True) -> None:
+	""" Limits the number of delta backups by consolidating the oldest ones.
+
+	If the number of backups exceeds max_backups, the oldest backups are consolidated
+	into a single backup file, then deleted, until the count is within the limit.
+
+	Args:
+		max_backups (int): Maximum number of delta backups to keep
+		backup_folder (str): Path to the folder containing backups
+		keep_oldest (bool): If True, never delete the oldest backup (default: True)
+	Examples:
+
+	.. code-block:: python
+
+		> limit_backups(5, "/path/to/backups")
+		[INFO HH:MM:SS] Limiting backups
+		[INFO HH:MM:SS] Consolidated 3 oldest backups into '/path/to/backups/consolidated_YYYY_MM_DD-HH_MM_SS.zip'
+		[INFO HH:MM:SS] Deleted 3 old backups
+	"""
+	backup_folder = clean_path(os.path.abspath(backup_folder))
+	if max_backups < 1:
+		raise ValueError("max_backups must be at least 1")
+
+	# Get all backup files sorted by date (oldest first), including consolidated ones
+	# Sort by timestamp (removing "consolidated_" prefix for proper chronological ordering)
+	def get_sort_key(filename: str) -> str:
+		basename = os.path.basename(filename)
+		return basename.replace("consolidated_", "")
+
+	backup_files: list[str] = sorted([
+		clean_path(os.path.join(backup_folder, f))
+		for f in os.listdir(backup_folder)
+		if f.endswith(".zip")
+	], key=get_sort_key)
+
+	backup_count: int = len(backup_files)
+
+	# Check if we need to consolidate
+	if backup_count <= max_backups:
+		info(f"Current backup count ({backup_count}) is within limit ({max_backups}). No action needed.")
+		return
+
+	# Calculate how many backups to consolidate
+	num_to_consolidate: int = backup_count - max_backups + 1
+
+	# If keep_oldest is True, exclude the oldest backup from consolidation
+	if keep_oldest and backup_count > 1:
+		# Start from index 1 instead of 0 to skip the oldest backup
+		backups_to_consolidate: list[str] = backup_files[1:num_to_consolidate+1]
+	else:
+		backups_to_consolidate: list[str] = backup_files[:num_to_consolidate]
+
+	latest_to_consolidate: str = backups_to_consolidate[-1]
+
+	info(f"Found {backup_count} backups, consolidating {num_to_consolidate} oldest backups...")
+
+	# Extract timestamp from the most recent backup being consolidated (last in list)
+	latest_backup: str = os.path.basename(backups_to_consolidate[-1])
+	latest_timestamp: str = latest_backup.replace("consolidated_", "").replace(".zip", "")
+
+	# Create consolidated backup filename with the most recent consolidated backup's timestamp
+	consolidated_filename: str = f"consolidated_{latest_timestamp}.zip"
+	consolidated_path: str = clean_path(os.path.join(backup_folder, consolidated_filename))	# Consolidate the oldest backups
+	consolidate_backups(latest_to_consolidate, consolidated_path)
+
+	# Delete the old backups that were consolidated
+	for backup_path in backups_to_consolidate:
+		try:
+			os.remove(backup_path)
+			info(f"Deleted old backup: {os.path.basename(backup_path)}")
+		except Exception as e:
+			warning(f"Error deleting backup {backup_path}: {e}")
+
+	info(f"Successfully limited backups to {max_backups}. Consolidated backup: {consolidated_filename}")
+
 # Function to compute the SHA-256 hash of a file
 def get_file_hash(file_path: str) -> str | None:
 	""" Computes the SHA-256 hash of a file.
