@@ -13,6 +13,7 @@ Components:
 - github: GitHub-specific utilities (upload_to_github)
 - pypi: PyPI publishing tools (pypi_full_routine)
 - pyproject: pyproject.toml file management
+- stubs: Stub file generation using pyright (stubs_full_routine)
 
 """
 # ruff: noqa: F403
@@ -22,4 +23,5 @@ from .cd_utils import *
 from .github import *
 from .pypi import *
 from .pyproject import *
+from .stubs import *
 
